Attributes#
|
Retrieve a value from the internal data using a given key. |
List keys available in internal dictionary. |
|
List values available in internal dictionary. |
|
List items available in internal dictionary. |
|
|
Parse a list of lines from a file and convert the data into a dictionary. |
Supported formats#
|
Convert PDB file data into a dictionary representation [Ra4c9f6a816d0-1]. |
|
Convert MMCIF file data into a dictionary representation. |
|
Convert GRO file in Gromos87 format into a dictionary representation [R9139f7711c9e-1]. |
|
Convert STAR file data into a dictionary representation [Rd1c0acc01191-1]. |
|
Parser for XML files. |
|
Convert MDOC file (SerialEM metadata) into a dictionary representation. |